import type { TrendAnalysis } from '../types/index.js';
/**
 * 趋势分析器
 * 提供高级的趋势识别、预测和分析功能
 */
export declare class TrendAnalyzer {
    /**
     * 分析热门趋势
     */
    analyzeTrends(timeRange?: number): Promise<TrendAnalysis>;
    /**
     * 按时间范围过滤数据
     */
    private filterByTimeRange;
    /**
     * 分析热门话题
     */
    private analyzeTrendingTopics;
    /**
     * 从文章中提取话题
     */
    private extractTopicsFromArticle;
    /**
     * 从沸点中提取话题
     */
    private extractTopicsFromPin;
    /**
     * 提取关键词
     */
    private extractKeywords;
    /**
     * 更新话题数据
     */
    private updateTopicData;
    /**
     * 计算文章参与度
     */
    private calculateArticleEngagement;
    /**
     * 计算沸点参与度
     */
    private calculatePinEngagement;
    /**
     * 计算话题分数
     */
    private calculateTopicScore;
    /**
     * 计算增长率
     */
    private calculateGrowthRate;
    /**
     * 评估趋势强度
     */
    private assessTrendStrength;
    /**
     * 分析热门标签
     */
    private analyzeHotTags;
    /**
     * 计算标签动量
     */
    private calculateTagMomentum;
    /**
     * 预测趋势发展
     */
    predictTrendEvolution(topic: string, _timeRange?: number): Promise<{
        topic: string;
        current_status: "hot" | "warm" | "cool";
        predicted_direction: "rising" | "stable" | "declining";
        confidence: number;
        key_factors: string[];
        recommended_actions: string[];
        prediction_time: string;
    }>;
    /**
     * 分析话题历史
     */
    private analyzeTopicHistory;
    /**
     * 创建时间段
     */
    private createTimeSlots;
    /**
     * 检查是否包含话题
     */
    private containsTopic;
    /**
     * 获取时间段索引
     */
    private getTimeSlot;
    /**
     * 生成趋势预测
     */
    private generateTrendPrediction;
    /**
     * 识别新兴趋势
     */
    identifyEmergingTrends(timeRange?: number): Promise<{
        time_range_hours: number;
        emerging_topics: {
            topic: string;
            mentions: number;
            engagement_rate: number;
            velocity: number;
            cross_platform: boolean;
            emergence_score: number;
        }[];
        analysis_time: string;
    }>;
    /**
     * 发现新兴话题
     */
    private findEmergingTopics;
    /**
     * 更新新兴话题数据
     */
    private updateEmergingTopicData;
    /**
     * 计算新兴度分数
     */
    private calculateEmergenceScore;
}
export declare const trendAnalyzer: TrendAnalyzer;
