/**
 * 抽奖和签到相关API
 * 注意：这些API通常需要用户认证，这里提供基础框架
 */
export declare class LotteryApi {
    /**
     * 获取当前矿石数
     */
    getCurrentOre(): Promise<unknown>;
    /**
     * 获取签到状态
     */
    getCheckInStatus(): Promise<unknown>;
    /**
     * 执行签到
     */
    checkIn(): Promise<unknown>;
    /**
     * 获取签到天数信息
     */
    getCheckInDays(): Promise<unknown>;
    /**
     * 抽奖
     */
    drawLottery(): Promise<unknown>;
    /**
     * 十连抽
     */
    drawTenLottery(): Promise<unknown>;
    /**
     * 获取奖品列表
     */
    getPrizeList(): Promise<unknown>;
    /**
     * 兑换奖品
     */
    exchangePrize(prizeId: string): Promise<unknown>;
    /**
     * 获取BUG列表
     */
    getBugList(): Promise<unknown>;
    /**
     * 收集BUG
     */
    collectBug(bugId: string): Promise<unknown>;
    /**
     * 获取成长等级信息
     */
    getGrowthLevel(): Promise<unknown>;
    /**
     * 获取今日代码日历
     */
    getTodayCodeCalendar(): Promise<unknown>;
    /**
     * 补签
     */
    makeUpCheckIn(date: string): Promise<unknown>;
    /**
     * 获取用户积分历史
     */
    getPointHistory(page?: number, limit?: number): Promise<unknown>;
    /**
     * 获取抽奖历史
     */
    getLotteryHistory(page?: number, limit?: number): Promise<unknown>;
    /**
     * 模拟获取公开的抽奖统计信息（不需要认证）
     */
    getLotteryStats(): Promise<{
        total_users: number;
        total_draws: number;
        total_prizes: number;
        popular_prizes: {
            name: string;
            count: number;
        }[];
        recent_winners: never[];
    }>;
    /**
     * 获取签到排行榜（模拟）
     */
    getCheckInRanking(limit?: number): Promise<{
        ranking: {
            rank: number;
            user_name: string;
            continuous_days: number;
            total_days: number;
        }[];
        total_users: number;
        my_rank: null;
    }>;
}
export declare const lotteryApi: LotteryApi;
