import { Config } from '../types/index.js';
/**
 * 默认配置
 */
export declare const defaultConfig: Config;
/**
 * 获取配置
 */
export declare function getConfig(): Config;
/**
 * 验证配置
 */
export declare function validateConfig(config: Config): {
    valid: boolean;
    errors: string[];
};
/**
 * 获取授权头信息
 */
export declare function getAuthHeaders(config: Config): Record<string, string>;
/**
 * 获取URL参数
 */
export declare function getUrlParams(config: Config): Record<string, string>;
/**
 * 检查是否启用授权功能
 */
export declare function isAuthEnabled(config: Config): boolean;
/**
 * 掘金API常量
 */
export declare const JUEJIN_CONSTANTS: {
    readonly SORT_TYPE: {
        readonly RECOMMEND: 200;
        readonly LATEST: 300;
        readonly HOT_3_DAYS: 3;
        readonly HOT_7_DAYS: 7;
        readonly HOT_30_DAYS: 30;
        readonly HOT_ALL: 0;
    };
    readonly CATEGORY_ID: {
        readonly FRONTEND: "6809637767543259144";
        readonly BACKEND: "6809637769959178254";
        readonly ANDROID: "6809635626879549454";
        readonly IOS: "6809635626661445640";
        readonly AI: "6809637773935378440";
    };
    readonly ITEM_TYPE: {
        readonly ARTICLE: 2;
        readonly ADVERT: 14;
        readonly PIN: 4;
    };
    readonly ENDPOINTS: {
        readonly ARTICLE_LIST: "/recommend_api/v1/article/recommend_all_feed";
        readonly PIN_LIST: "/recommend_api/v1/short_msg/recommend";
        readonly USER_INFO: "/user_api/v1/user/get";
        readonly CATEGORY_LIST: "/tag_api/v1/query_category_list";
        readonly TAG_LIST: "/tag_api/v1/query_tag_list";
    };
};
