/**
 * 项目包信息接口
 */
export interface PackageInfo {
    name: string;
    version: string;
    description: string;
    author: {
        name: string;
        email: string;
        url: string;
    };
    repository: {
        type: string;
        url: string;
    };
    homepage: string;
    bugs: {
        url: string;
    };
    license: string;
    keywords: string[];
}
/**
 * 获取项目包信息（缓存版本）
 */
export declare function getPackageInfo(): PackageInfo;
/**
 * 获取项目名称
 */
export declare function getProjectName(): string;
/**
 * 获取项目版本
 */
export declare function getProjectVersion(): string;
/**
 * 获取项目描述
 */
export declare function getProjectDescription(): string;
/**
 * 获取作者信息
 */
export declare function getAuthorInfo(): {
    name: string;
    email: string;
    url: string;
};
/**
 * 获取仓库信息
 */
export declare function getRepositoryInfo(): {
    type: string;
    url: string;
};
/**
 * 获取GitHub仓库URL（清理后的）
 */
export declare function getGitHubUrl(): string;
/**
 * 获取项目主页URL
 */
export declare function getHomepageUrl(): string;
/**
 * 获取完整的服务器信息对象
 */
export declare function getServerInfo(): {
    name: string;
    version: string;
    description: string;
    author: string;
    homepage: string;
    protocolVersion: string;
};
/**
 * 获取用于CLI显示的品牌信息
 */
export declare function getBrandInfo(): {
    name: string;
    version: string;
    description: string;
    fullName: string;
    displayName: string;
    githubUrl: string;
    homepageUrl: string;
};
